/*********************************FILE_HEADER***********************************
/**\file 		Z31x_api.h
 **\Copyright	HP Inc.
 **\brief 		Header file for APIs
 **/
/**--------------------------Change Record---------------------------------------------------------------------
 **    Author			Version        	Date			Description
 ** --------------------------------------------------------------------------------------------------------------
 * Ranjith				0.9				27-Jan-2017		Initial version
 * Ranjith              1.0             14-Nov-2017     Added Z31x-G2 support
 *******************************************************************************************************************/
#ifndef _Z31x_API_H_
#define _Z31x_API_H_

#include "common.h"

EXPORT_API STATUS Scan(BYTE byDisplayName[MAX_DISPLAYS][SERIALNUMBER_SIZE]);
EXPORT_API STATUS Connect(BYTE iID);
EXPORT_API STATUS Disconnect(void);

//GROUP_COLOR_SPACE_INFO

EXPORT_API STATUS GetDisplayLuminance(SWORD16 *ps16Val);
EXPORT_API STATUS SetDisplayLuminance(SWORD16 s16Val);
EXPORT_API STATUS GetActiveColorSpace(UBYTE *pu8Val);
EXPORT_API STATUS SetActiveColorSpace(UBYTE u8Val);
EXPORT_API STATUS GetDownstreamRGBAdjust(SWORD16 u8RGBGain[3], SWORD16 u8RGBOffset[3]);
EXPORT_API STATUS SetDownstreamRGBAdjust(SWORD16 u8RGBGain[3], SWORD16 u8RGBOffset[3]);
EXPORT_API STATUS GetBlueLightModeStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetBlueLightModeStatus(UBYTE u8Val);
//PRIMARIES
EXPORT_API STATUS GetCurrentColorSpaceName(BYTE byVal[COLOR_PRESET_NAME_LENGTH]);
EXPORT_API STATUS GetRedPrimaryXY(float* X, float* Y);
EXPORT_API STATUS GetRedPrimaryUV(float* U, float* V);
EXPORT_API STATUS GetGreenPrimaryXY(float* X, float* Y);
EXPORT_API STATUS GetGreenPrimaryUV(float* U, float* V);
EXPORT_API STATUS GetBluePrimaryXY(float *X, float *Y);
EXPORT_API STATUS GetBluePrimaryUV(float *U, float *V);
EXPORT_API STATUS GetWhitePrimaryXY(float *X, float *Y);
EXPORT_API STATUS GetWhitePrimaryUV(float *U, float *V);
EXPORT_API STATUS GetGamma(BYTE byVal[15]);
EXPORT_API STATUS GetPresetNameList(BYTE pbyVal[COLOR_PRESET_NUM][COLOR_PRESET_NAME_LENGTH]);

//GROUP_VIDEO_INPUT_SETTINGS
EXPORT_API STATUS GetActiveVideoInput(UBYTE *pu8Val);
EXPORT_API STATUS SetActiveVideoInput(UBYTE u8Val);
EXPORT_API STATUS GetAutoSwitchStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetAutoSwitchStatus(UBYTE u8Val);
EXPORT_API STATUS GetVideoInputName(UBYTE u8videoInputNo, BYTE bycustomName[VIDEO_INPUT_NAME_LENGTH], UBYTE *pu8customNameStatus);
EXPORT_API STATUS SetVideoInputName(UBYTE u8videoInputNo, UBYTE u8videoInputNameType, BYTE customName[VIDEO_INPUT_NAME_LENGTH]);
EXPORT_API STATUS GetUSBPortBindingStatus(UBYTE *pu8USBPortbindingStatus);
EXPORT_API STATUS SetUSBPortBindingStatus(UBYTE u8USBPortbindingStatus);
EXPORT_API STATUS GetUSBBindingConfiguration(UBYTE *pu8USB1Binding, UBYTE *pu8USB2Binding);
EXPORT_API STATUS SetUSBBindingConfiguration(UBYTE u8USB1Binding, UBYTE u8USB2Binding);

//GROUP_IMAGE_ADJUSTMENT
EXPORT_API STATUS GetImageScaling(UBYTE *pu8AspectRatio, UBYTE *pu8PixelStatus); 
EXPORT_API STATUS SetImageScaling(UBYTE u8AspectRatio, UBYTE u8PixelStatus);
EXPORT_API STATUS GetDciImageRegion(UBYTE *pu8Val);
EXPORT_API STATUS SetDciImageRegion(UBYTE u8Val);
EXPORT_API STATUS GetShowCroppedRegionStatus(UBYTE *pu8Val); 
EXPORT_API STATUS SetShowCroppedRegionStatus(UBYTE u8Val);
EXPORT_API STATUS GetCroppedRegionOpacity(UBYTE *pu8Val); 
EXPORT_API STATUS SetCroppedRegionOpacity(UBYTE u8Val);
EXPORT_API STATUS GetVideoLegalStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetVideoLegalStatus(UBYTE u8Val);
EXPORT_API STATUS GetOverScanStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetOverScanStatus(UBYTE u8Val);
EXPORT_API STATUS GetBlueChannelStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetBlueChannelStatus(UBYTE u8Val);
EXPORT_API STATUS GetOverDriveStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetOverDriveStatus(UBYTE u8Val);
EXPORT_API STATUS GetDeinterlacerStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetDeinterlacerStatus(UBYTE u8Val);
EXPORT_API STATUS GetCadenceDetectionStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetCadenceDetectionStatus(UBYTE u8Val);

EXPORT_API STATUS ClearMarkers();
EXPORT_API STATUS GetMarkerDetails(MarkerStatus *psMarkerDetails);
EXPORT_API STATUS SetMarkerDetails(const MarkerStatus* psMarkerDetails);
EXPORT_API STATUS GetMarkerColor(UBYTE *u8MarkerColor);
EXPORT_API STATUS SetMarkerColor(UBYTE u8MarkerColor);


//GROUP_PIP_SETTINGS
EXPORT_API STATUS GetPIPStatus(UBYTE *pu8PIPStatus);
EXPORT_API STATUS SetPIPStatus(UBYTE u8PIPStatus);
EXPORT_API STATUS GetPIPMode(UBYTE *u8PIPMode);
EXPORT_API STATUS SetPIPMode(UBYTE u8PIPMode);
EXPORT_API STATUS GetPIPPosition(UBYTE *pu8PIPPositionStatus, SWORD16 *ps16XValue, SWORD16 *ps16YValue);
EXPORT_API STATUS SetPIPPosition(UBYTE u8PIPPositionStatus, SWORD16 s16XValue, SWORD16 s16YValue);
EXPORT_API STATUS GetPIPSize(UBYTE *pu8PIPSizeStatus, SWORD16 *ps16XValue, SWORD16 *ps16YValue);
EXPORT_API STATUS SetPIPSize(UBYTE u8PIPSizeStatus, SWORD16 s16Height);
EXPORT_API STATUS GetPIPPrimaryInput(UBYTE *pu8Val); 
EXPORT_API STATUS SetPIPPrimaryInput(UBYTE u8Val);
EXPORT_API STATUS GetPIPSecondaryInput(UBYTE *pu8Val);
EXPORT_API STATUS SetPIPSecondaryInput(UBYTE u8Val);
EXPORT_API STATUS GetSwapPIPInputsStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetSwapPIPInputsStatus(UBYTE u8Val);
EXPORT_API STATUS GetPIPVideoLegalStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetPIPVideoLegalStatus(UBYTE u8Val);
EXPORT_API STATUS GetPIPOverscanStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetPIPOverscanStatus(UBYTE u8Val);
EXPORT_API STATUS GetPIPDciStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetPIPDciStatus(UBYTE u8Val);

EXPORT_API STATUS ClearPIPMarkers();
EXPORT_API STATUS GetPIPMarkerDetails(MarkerStatus *psMarkerDetails);
EXPORT_API STATUS SetPIPMarkerDetails(const MarkerStatus* psMarkerDetails);
EXPORT_API STATUS GetPIPMarkerColor(UBYTE *u8MarkerColor);
EXPORT_API STATUS SetPIPMarkerColor(UBYTE u8MarkerColor);

//GROUP_LOAD_SAVE_USER_PRESET
EXPORT_API STATUS LoadUserPreset(UBYTE u8LoadUserPresetNo);
EXPORT_API STATUS SaveUserPreset(UBYTE u8SaveUserPresetNo);

//GROUP_CALIBRATION

EXPORT_API STATUS GetCalibrationSchedule(ScheduledCalibInfo* psScheduledCalibInfo);
EXPORT_API STATUS SetCalibrationSchedule(const ScheduledCalibInfo* psScheduledCalibInfo);
EXPORT_API STATUS GetDisplayWarmupSettings(WarmupSettings* psWarmupSettings);
EXPORT_API STATUS SetDisplayWarmupSettings(const WarmupSettings* psWarmupSettings);
EXPORT_API STATUS RecalibrateActivePreset();
EXPORT_API STATUS ConfigureAndCalibratePreset(UBYTE u8colorPreset, UBYTE u8colorGamut, UBYTE u8whitePoint, UBYTE u8gamma, UBYTE u8luminance);

//GROUP_CONFIG
EXPORT_API STATUS GetAutoSleepMode(UBYTE *pu8Val);
EXPORT_API STATUS SetAutoSleepMode(UBYTE u8Val);
EXPORT_API STATUS GetPowerOnRecallStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetPowerOnRecallStatus(UBYTE u8Val);
EXPORT_API STATUS GetDDCCICommnStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetDDCCICommnStatus(UBYTE u8Val);
EXPORT_API STATUS GetAutoEDIDUpdateStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetAutoEDIDUpdateStatus(UBYTE u8Val);
EXPORT_API STATUS GetHotPlugInitiateStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetHotPlugInitiateStatus(UBYTE u8Val);
EXPORT_API STATUS PowerOffManageInternalProcessor();
EXPORT_API STATUS GetFirmwareUpdateStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetFirmwareUpdateStatus(UBYTE u8Val);
EXPORT_API STATUS GetCalibrationStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetCalibrationStatus(UBYTE u8Val);
EXPORT_API STATUS SetDPHPDStatus(UBYTE u8Val);
EXPORT_API STATUS GetDPHPDStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetUserPresetSupportStatus(UBYTE u8EnableUserPresetSupportStatus);
EXPORT_API STATUS GetUserPresetSupportStatus(UBYTE *pu8EnableUserPresetSupportStatus);
EXPORT_API STATUS SetDateAndTime(const ClockSettings *psClockSettings);
EXPORT_API STATUS GetDateAndTime(ClockSettings *psClockSettings);
EXPORT_API STATUS SetAutoAdjustDateAndTimeStatus(UBYTE u8AutoAdjustDateTime);
EXPORT_API STATUS GetAutoAdjustDateAndTimeStatus(UBYTE *pu8AutoAdjustDateTime);
EXPORT_API STATUS SetDeviceTimeFormat(UBYTE u8TimeFormatStatus);
EXPORT_API STATUS GetDeviceTimeFormat(UBYTE *pu8TimeFormatStatus);
EXPORT_API STATUS SetAutoAdjustDayLightSavingStatus(UBYTE u8AutoAdjustDayLightSAving);
EXPORT_API STATUS GetAutoAdjustDayLightSavingStatus(UBYTE *pu8AutoAdjustDayLightSAving);
EXPORT_API STATUS SetAllowExternalInstrumentStatus(UBYTE u8EnableExternalInstrumentStatus);
EXPORT_API STATUS GetAllowExternalInstrumentStatus(UBYTE *pu8EnableExternalInstrumentStatus);
EXPORT_API STATUS AlignInternalCalibrationDevice();

EXPORT_API STATUS SetTimezone(UBYTE u8Timezoneinfo);
EXPORT_API STATUS GetTimezone(UBYTE *pu8Timezoneinfo);
EXPORT_API STATUS GetUSBSleepFunctionality(UBYTE *pu8Val);
EXPORT_API STATUS SetUSBSleepFunctionality(UBYTE u8Val);
EXPORT_API STATUS GetLuminanceUniformityStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetLuminanceUniformityStatus(UBYTE u8Val);
EXPORT_API STATUS GetDPEDIDConfiguration(UBYTE *pu8Val);
EXPORT_API STATUS SetDPEDIDConfiguration(UBYTE u8Val);
EXPORT_API STATUS LockManagementMenu(UBYTE u8Val);
EXPORT_API STATUS SetUSBCInputConfiguration(UBYTE u8USBCConfig);
EXPORT_API STATUS GetUSBCInputConfiguration(UBYTE *pu8USBCConfig);
//Reset Commands
EXPORT_API STATUS FactoryReset();

//GROUP_OSD_SETTINGS
EXPORT_API STATUS GetOSDPosition(SWORD16 *X, SWORD16 *Y);
EXPORT_API STATUS SetOSDPosition(SWORD16 X, SWORD16 Y);
EXPORT_API STATUS GetOSDOpacity(UBYTE *pu8Val);
EXPORT_API STATUS SetOSDOpacity(UBYTE u8Val);
EXPORT_API STATUS GetOSDTimeout(UBYTE *pu8Val);
EXPORT_API STATUS SetOSDTimeout(UBYTE u8Val);
EXPORT_API STATUS GetShowPowerOnInfoStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetShowPowerOnInfoStatus(UBYTE u8Val);
EXPORT_API STATUS GetShowInputSourceInfoStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetShowInputSourceInfoStatus(UBYTE u8Val);
EXPORT_API STATUS GetShowColorspaceInfoStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetShowColorspaceInfoStatus(UBYTE u8Val);
EXPORT_API STATUS GetShowWarmupTimeReminderStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetShowWarmupTimeReminderStatus(UBYTE u8Val);
EXPORT_API STATUS GetShowCalibrationNotificationStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetShowCalibrationNotificationStatus(UBYTE u8Val);
EXPORT_API STATUS GetMenuLanguage(UBYTE *pu8Val);
EXPORT_API STATUS SetMenuLanguage(UBYTE u8Val);

//GROUP_FUNCTION_BTN_SETTINGS
EXPORT_API STATUS GetFunctionButtonSettings(SWORD16 s16Button, SWORD16 *ps16Val);
EXPORT_API STATUS SetFunctionButtonSettings(SWORD16 s16Button, SWORD16 s16Val);
EXPORT_API STATUS GetFunctionButtonMode(UBYTE *pu8Val);
EXPORT_API STATUS SetFunctionButtonMode(UBYTE u8Val);

//GROUP_BEZEL_BTN_SETTINGS
EXPORT_API STATUS GetBezelButtonColor(UBYTE *pu8Val);
EXPORT_API STATUS SetBezelButtonColor(UBYTE u8Val);
EXPORT_API STATUS GetBezelButtonBrightness(UBYTE *pu8Val);
EXPORT_API STATUS SetBezelButtonBrightness(UBYTE u8Val);
EXPORT_API STATUS GetBezelButtonAutoFadeStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetBezelButtonAutoFadeStatus(UBYTE u8Val);
//GROUP_REMOTE_CONFIG

EXPORT_API STATUS GetWebServerStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetWebServerStatus(UBYTE u8Val);
EXPORT_API STATUS GetIPConfiguration(IPConfig *psIPConfig , BYTE *pbyMacAddress);
EXPORT_API STATUS SetIPConfiguration(const IPConfig *psIPConfig);
EXPORT_API STATUS SetWSManagementStatus(UBYTE u8Val);
EXPORT_API STATUS GetWSManagementStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetWSIdentifySupportStatus(UBYTE u8Val);
EXPORT_API STATUS GetWSIdentifySupportStatus(UBYTE *pu8Val);
EXPORT_API STATUS SetDashboardSecurity(UBYTE u8dashBoardStatus);
EXPORT_API STATUS GetDashboardSecurityStatus(UBYTE *u8dashBoardStatus);

//GROUP_MONITOR_INFO
EXPORT_API STATUS GetFirmwareRevision(BYTE *pbyVal);
EXPORT_API STATUS GetDisplaySerialNumber(BYTE *pbyVal);
EXPORT_API STATUS GetDisplayMode(BYTE *pbyVal);
EXPORT_API STATUS GetCalibrationHours(SWORD16 *ps16Val);
EXPORT_API STATUS GetBacklightHours(SWORD16 *ps16Val);

//STUDIO CALIBRATION XML
EXPORT_API STATUS SendFileToDisplay(FILE_TYPE FileType, char *FileName);
EXPORT_API STATUS ValidateStudiocalXML();
EXPORT_API STATUS PerformStudioCalibration();
EXPORT_API STATUS GetFileFromDisplay(FILE_TYPE FileType, char *FolderName);

//TEST PATTERNS
EXPORT_API STATUS EnableTestPattern();
EXPORT_API STATUS ShowTestPatternforUserMode(SWORD16 R, SWORD16 G, SWORD16 B);
EXPORT_API STATUS ShowTestPatternServiceMode(TEST_PATTERN Color);
EXPORT_API STATUS DisableTestPattern();
EXPORT_API STATUS GetTestPatternStatus(UBYTE *pu8Val);

//Remote Profile Details
EXPORT_API STATUS GetCustomerIDAsset(BYTE byCustomerAssetTag[MONITOR_PROFILE_STRING_LENGTH]);
EXPORT_API STATUS GetDisplayName(BYTE byDisplayName[MONITOR_PROFILE_STRING_LENGTH]);
EXPORT_API STATUS GetDeploymentLocation(BYTE byDeploymentLocation[MONITOR_PROFILE_STRING_LENGTH]);
EXPORT_API STATUS GetDeploymentDate(BYTE byDeploymentDate[11]);
EXPORT_API STATUS GetSdkVersion(BYTE byVersion[10]);

//MonitorConfiguration
EXPORT_API STATUS GetColorManagementEngineStatus(UBYTE *pu8Val);
EXPORT_API STATUS GetDitheringModeStatus(UBYTE *pu8Val);
EXPORT_API STATUS GetCalibrationAlertLimit(UBYTE *pu8Val);

EXPORT_API STATUS SetLog(UBYTE u8Val);

#endif
