/*********************************FILE_HEADER*********************************************************************
/**\file 		common.h
 **\Copyright	HP Inc.
 **\brief 		Structures and typedef used in APIs
 **/
/**--------------------------Change Record---------------------------------------------------------------------
 **    Author			Version        	Date			Description
 ** --------------------------------------------------------------------------------------------------------------
 * Ranjith				0.9			    27-Jan-2017			Initial 
 * Ranjith              1.0             14-Nov-2017     Added Z31x-G2 support
 *******************************************************************************************************************/

 
#ifndef __COMMON_DEFS_H__
#define __COMMON_DEFS_H__

#if defined WIN32 || defined WIN64
#include <windows.h>
#endif

#if defined WIN32 || defined WIN64
#define EXPORT_API 		__declspec(dllexport) 
#elif linux || defined __APPLE__
#define EXPORT_API 		
#endif

#if defined linux || defined __APPLE__
#define PBYTE			BYTE*
typedef signed char		BYTE;
typedef unsigned char 	BOOL;
#endif

typedef unsigned char	UBYTE;
typedef unsigned short	UWORD16;
typedef unsigned int	UWORD32;
typedef signed short	SWORD16;
typedef signed int		SWORD32;

#define TRUE	1
#define FALSE	0

#define MAX_DISPLAYS		3
#define SERIALNUMBER_SIZE	12
#define COLOR_PRESET_NAME_LENGTH 	15
#define COLOR_PRESET_NUM		8
#define VIDEO_INPUT_NAME_LENGTH 	15
#define IP_STRING_LENGTH    (16)
#define MONITOR_PROFILE_STRING_LENGTH 19


//Error Status for APIs
typedef enum 
{
	STATE_ER_OPEN = -12,
	STATE_ER_ENUM,
	STATE_ER_NO_DEV,
	STATE_ER_TIMEOUT,
	STATE_ER_CLAIM_INTERFACE,
	STATE_ER_INVALID_ARG,
	STATE_ER_NOT_CONNECTED,
	STATE_ER_COMM,
	STATE_ER_API,
	STATE_ER_API_NOT_SUPPORTED,
	STATE_ER_MONITOR_MODE,
	FAILURE = -1,
	SUCCESS = 0,
	CONTINUE = 1
}
STATUS;  

//Test pattern list for service mode
typedef enum
{
	BLACK_ONLY,	
	DARKGREY_ONLY,	
	WHITE_ONLY,	
	RED_ONLY,	
	GREEN_ONLY,	
	BLUE_ONLY,	
	CYAN_ONLY,
	MAGENTA_ONLY,
	YELLOW_ONLY,
	GREY_SCALE_LINEAR_RAMP
}
TEST_PATTERN;

typedef enum
{
	STUDIOCAL_XML,
	UPLOAD_LUT_ZIP,
	MONITOR_SETTINGS,
	DOWNLOAD_LUT_ZIP,
	VALIDATION_RESULTS,
	SAVED_MONITOR_SETTINGS,
	ICC_PROFILE,
	LOAD_USER_PRESET,
	SAVED_USER_PRESET
}
FILE_TYPE;

typedef enum
{
	NORMAL_GAMMA = 0,
	CUSTOM_GAMMA = 1
}
GAMMA_TYPE;

//Primary details used in ColorSpaceDetails
#pragma pack(push,1)
struct __Primaries 
{              
	float x;
	float y;
};
typedef struct __Primaries Primaries;

struct __GammaDetails
{
	GAMMA_TYPE Type;
	union
	{
		BYTE Name[10];
		float Value;
	}
	GammaValue;
};
typedef struct __GammaDetails GammaDetails;

//Colorspace details for performing LUT upload/ download
struct __ColorSpaceDetails
{              
	Primaries Red;
	Primaries Green;
	Primaries Blue; 
	Primaries WhitePoint;	
	GammaDetails Gamma;
	UBYTE Luminance; 
	UBYTE use_uv;
};
typedef struct __ColorSpaceDetails ColorSpaceDetails;

struct __MarkerStatus
{
        UBYTE ClearAll;
	    UBYTE AR_1_85_1;
        UBYTE AR_2_39_1;
        UBYTE Extraction_16_9;
        UBYTE ActionSafe_16_9;
        UBYTE TitleSafe_16_9;
        UBYTE Extraction_4_3;
        UBYTE ActionSafe_4_3;
        UBYTE TitleSafe_4_3;
        UBYTE Centre;
        UBYTE Thirds;
        UBYTE User;

};
typedef struct __MarkerStatus MarkerStatus;


struct __DateSettings
{
	UBYTE Month;
	UBYTE Day;
	SWORD16 Year;
};
typedef struct __DateSettings DateSettings;

struct __TimeSettings
{
	UBYTE Hour;
	UBYTE Minute;
};
typedef struct __TimeSettings TimeSettings;

struct __ClockSettings
{
	DateSettings sDate;
	TimeSettings sTime;
	UBYTE Timezoneinfo;
	UBYTE Timeformat;
	UBYTE TimeMeridian;
};
typedef struct __ClockSettings ClockSettings;

struct __WarmupSettings
{
	UBYTE WarmupEnableStatus;
	UBYTE WarmupTimeHour;
	UBYTE WarmupTimeMinute;
	UBYTE WarmuptimeMeridian;
	UBYTE WarmupEnableSunday;
	UBYTE WarmupEnableMonday;
	UBYTE WarmupEnableTuesday;
	UBYTE WarmupEnableWednesday;
	UBYTE WarmupEnableThursday;
	UBYTE WarmupEnableFriday;
	UBYTE WarmupEnableSaturday;
};
typedef struct __WarmupSettings WarmupSettings;
struct __ScheduledCalibInfo
{
	UBYTE ScheduleStatus;
	UBYTE FrequencyType;
	SWORD16 FrequencyCount;
	UBYTE DayofWeek;
	UBYTE TimeHH;
	UBYTE TimeMM;
	UBYTE TimeMeridian;
};
typedef struct __ScheduledCalibInfo ScheduledCalibInfo;
struct __IpConfig
{
	UBYTE IPMode;
	BYTE IPAddress[IP_STRING_LENGTH];
	BYTE SubnetMask[IP_STRING_LENGTH];
	BYTE Gateway[IP_STRING_LENGTH];
} ;
typedef struct __IpConfig IPConfig;
#pragma pack(pop)


#define LUMINANCE_MAX 250
#define LUMINANCE_MIN 48

#define COLORSPACE_COUNT 8
#define RGB_OFFSET_MIN 0
#define RGB_OFFSET_MAX 1023
#define RGB_GAIN_MIN 0
#define RGB_GAIN_MAX 1023

#define VIDEO_INPUT_MAX 4
#define USB_PORT_BINDING_MAX 3
#define MARKER_COLOR_MAX 6
#define USER_PRESET_COUNT 4



#endif /*__COMMON_DEFS_H__*/
